@@ -113,7 +113,7 @@ def read_file(home, file_name):
     data = ''
     try:
         f = open(os.path.join(os.environ.get(home), file_name), 'r+')
-        data = f.readline()
+        data = str(f.readline()).strip()
         f.close()
     finally:
         return data
@@ -331,10 +331,10 @@ def go(batch=False):
             with open(cmdlinepath) as f:
                 content = f.read()
                 if content:
-                    return content.encode('utf8')
+                    return content.strip()
         return ''
     pid = read_file(home, file_name)
-    if pid and 'whatap_python' in get_pname(pid):
+    if pid and get_pname(pid).find('whatap_python') >= 0:
         return
     try:
         home_path= os.environ.get(home)
@@ -355,6 +355,8 @@ def go(batch=False):
         # Write PID file
         write_file(home, file_name, str(process.pid))
     except Exception as e:
+        import traceback
+        traceback.print_exc()
         print('WHATAP: AGENT ERROR: {}'.format(e))
     else:
         print('WHATAP: AGENT UP! (process name: {})\n'.format(AGENT_NAME))
